#!/bin/bash
# Servlets
export CLASSPATH=.:$TOMCAT_HOME/common/lib/servlet-api.jar
# Web Services
export CLASSPATH=$CLASSPATH:$AXIS_HOME:$AXIS_HOME/lib/axis.jar:$AXIS_HOME/lib/jaxrpc.jar:$AXIS_HOME/lib/saaj.jar:$AXIS_HOME/lib/commons-logging.jar:$AXIS_HOME/lib/commons-discovery.jar:$AXIS_HOME/lib/wsdl4j.jar:$TOMCAT_HOME/webapps/axis/WEB-INF/lib/xerces.jar

# Logic JAR
#export CLASSPATH=$CLASSPATH:$TOMCAT_HOME/shared/lib/Counter.jar
