package CounterWS;

import Counter.CounterController;

public class CounterImpl {

    static CounterController cc = CounterController.getInstance();

    public int incrementCounter() {
        return cc.incrementCounter();
    }
}
