import CounterWS.ws.CounterInterface;
import CounterWS.ws.CounterInterfaceService;
import CounterWS.ws.CounterInterfaceServiceLocator;

public class Tester {

    public static void main (String [] args) throws Exception {
        CounterInterfaceService service = new CounterInterfaceServiceLocator();

        CounterInterface counter = service.getCounter();

        System.out.println("Visitas: " + counter.incrementCounter());
    }
    
}
